@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: persistent
-version: 2.2.4.1
-id: persistent-2.2.4.1-53b32e0b8931dd68fbb356ac374c65f3
-key: persi_J2ytUYAzvbAKKp3CvCQURI
+version: 2.2.4
+id: persistent-2.2.4-7522deb7fd39c262180984fc189631e9
+key: persi_5ADFnEQwbUn7KjyX4rJFOV
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
 stability: Stable
@@ -32,41 +32,41 @@ hidden-modules: Database.Persist.Types.Base
                 Database.Persist.Sql.Orphan.PersistStore
                 Database.Persist.Sql.Orphan.PersistUnique
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-2.2.4.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-2.2.4.1
-data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-2.2.4.1
-hs-libraries: HSpersistent-2.2.4.1-J2ytUYAzvbAKKp3CvCQURI
+import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-2.2.4
+library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-2.2.4
+data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-2.2.4
+hs-libraries: HSpersistent-2.2.4-5ADFnEQwbUn7KjyX4rJFOV
 depends:
-    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
-    attoparsec-0.13.0.2-669cbb29a91e49834657a781d3adc2de
+    aeson-0.10.0.0-b63a88a6e7bf231c11601ff561c0eb0d
+    attoparsec-0.13.0.1-57451b44323b331c08be1b712bdc3810
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
-    blaze-html-0.8.1.1-196db2ddcb827bc04473411dd00dd5eb
-    blaze-markup-0.7.0.3-301d79472dd24aabecf5f1be193f6bdb
+    blaze-html-0.8.1.1-b598557be4ce3598e270c7592be1f33c
+    blaze-markup-0.7.0.3-adfaa12a6c8f95338d1eda4a379eb541
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.6-d359386885a03b60281b91c4e140d8f4
+    conduit-1.2.6.1-99a58e37479a2070047844a872c4445f
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
-    fast-logger-2.4.6-432abdc0f5b043114ea69b7c4625cae5
-    http-api-data-0.2.2-d85b0db99d6d5995d772ab01cd2ae49e
-    lifted-base-0.2.3.6-9c13caa8bbd360a88b87891885feeeff
-    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
-    monad-logger-0.3.18-1374b457a8b7165408364c0bd477c532
+    fast-logger-2.4.1-3a82ef8da5665c7f13125a65809925c9
+    http-api-data-0.2.2-d3c9f175f1f98718629e761de86ea99f
+    lifted-base-0.2.3.6-d9ded25fdcc56319fed7ad1fd7194bcc
+    monad-control-1.0.0.4-fa18b603f1c859e06ea8fbebdf00a3e7
+    monad-logger-0.3.17-6bebcabc98fb90582d59aab2ac8cf400
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
-    path-pieces-0.2.1-f62a4ee86afe2692f9fb79d2dd895499
-    resource-pool-0.2.3.2-4273363c3eb17da3d6b84d801cb4d318
-    resourcet-1.1.7.4-51f149abafdcf0369a30d929df00de54
-    scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
+    path-pieces-0.2.1-1993cf7409b1066d7297872970b0fe71
+    resource-pool-0.2.3.2-bd63600cbb4b1187bb6a3c1ed6e4569b
+    resourcet-1.1.7-7e93b08fc7a9dc3281fd76904261e146
+    scientific-0.3.4.4-2c552cd0c6d8817341c76144fa370151
     silently-1.2.5-7f926db5f44f7696c1a8c4ab976d4845
-    tagged-0.8.4-af2e23230031c45949e0062e776a8f1f
+    tagged-0.8.2-849e3b2865ae1877e32ec9d4d01c3d0a
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
-    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
+    text-1.2.1.3-6c3c87c392cdf2c29fca1c10bbf7250b
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
-    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
-    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
+    unordered-containers-0.2.6.0-08e36bb27daebf8e082345cc5a0772e7
+    vector-0.11.0.0-c9b9eff80d809aeb097685ce86af03c4
 haddock-interfaces: /usr/share/doc/haskell-persistent/html/persistent.haddock
 haddock-html: /usr/share/doc/haskell-persistent/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
